@@ -19,6 +19,7 @@ require 'json'
 require 'digest/md5'
 require 'base64'
 require 'nokogiri'
+require 'set'
 
 module AWS
   class S3
@@ -26,12 +27,24 @@ module AWS
     # Client class for Amazon Simple Storage Service (S3).
     class Client < Core::Client
 
+      include RegionDetection
+
+      def initialize(options = {})
+        super(options.merge(:http_continue_threshold => 0))
+      end
+
       signature_version :S3
 
       API_VERSION = '2006-03-01'
 
       XMLNS = "http://s3.amazonaws.com/doc/#{API_VERSION}/"
 
+      HTTP_200_ERROR_OPERATIONS = Set.new([
+        :complete_multipart_upload,
+        :copy_object,
+        :copy_part,
+      ])
+
       autoload :XML, 'aws/s3/client/xml'
 
       # @api private
@@ -51,14 +64,11 @@ module AWS
       # @param [Core::Http::Request] request
       # @api private
       def sign_request request
-        version = @config.s3_signature_version ?
-          @config.s3_signature_version.to_sym :
-          (@region =~ /cn-/ ? :v4 : :v3)
-        case version
+        case @config.s3_signature_version.to_sym
         when :v4 then v4_signer.sign_request(request)
         when :v3 then v3_signer.sign_request(request)
         else
-          raise "invalid signature version #{version.inspect}"
+          raise "invalid signature version #{@config.s3_signature_version.inspect}"
         end
       end
 
@@ -165,8 +175,10 @@ module AWS
 
       def extract_error_details response
         if
-          (response.http_response.status >= 300 ||
-            response.request_type == :complete_multipart_upload) and
+          (
+            response.http_response.status >= 300 ||
+            HTTP_200_ERROR_OPERATIONS.include?(response.request_type)
+          ) and
           body = response.http_response.body and
           error = Core::XML::Parser.parse(body) and
           error[:code]
@@ -193,16 +205,22 @@ module AWS
       end
 
       def retryable_error? response
-        super or
-        failed_multipart_upload?(response) or
+        super ||
+        http_200_error?(response) ||
         response.error.is_a?(Errors::RequestTimeout)
       end
 
-      # S3 may return a 200 response code in response to complete_multipart_upload
-      # and then start streaming whitespace until it knows the final result.
-      # At that time it sends an XML message with success or failure.
-      def failed_multipart_upload? response
-        response.request_type == :complete_multipart_upload &&
+      # S3 may return with a 200 status code in the response, but still
+      # embed an error in the body for the following operations:
+      #
+      # * `#complete_multipart_upload`
+      # * `#copy_object`
+      # * `#copy_part`
+      #
+      # To ensure the response is not in error, we have to parse
+      # it before the normal parser.
+      def http_200_error? response
+        HTTP_200_ERROR_OPERATIONS.include?(response.request_type) &&
         extract_error_details(response)
       end
 
@@ -1417,6 +1435,9 @@ module AWS
       #   @param [Hash] options
       #   @option options [required,String] :bucket_name
       #   @option options [required,String] :key
+      #   @option options [String] :request_payer If specified, the request
+      #     will contain the specified String value in the x-amz-request-payer
+      #     header. This is required for Requester Pays enabled buckets.
       #   @option options [Time] :if_modified_since If specified, the
       #     response will contain an additional `:modified` value that
       #     returns true if the object was modified after the given
@@ -1454,6 +1475,7 @@ module AWS
       #
       object_method(:get_object, :get,
                     :header_options => {
+                      :request_payer => "x-amz-request-payer",
                       :if_modified_since => "If-Modified-Since",
                       :if_unmodified_since => "If-Unmodified-Since",
                       :if_match => "If-Match",
